
def printlist(add_to_list):
    list_grocries = []
    print "a list of things"
    list_groceries = ["milk", "bread", "carrot", "cheese", "butter"]
    list_groceries.append(add_to_list)
    return list_groceries
    

#printlist("cream")
